@@ -2143,6 +2143,21 @@ retvalue updates_update(struct update_distribution *distributions, bool nolistsd
 		r = space_check(cache->devices);
 		RET_ENDUPDATE(result, r);
 	}
+	if (!RET_WAS_ERROR(result) && !todo) {
+		for (d=distributions ; !todo && d != NULL ; d=d->next) {
+			struct update_target *u;
+			if (d->distribution->omitted)
+				continue;
+			for (u = d->targets ; u != NULL ; u = u->next) {
+				if (u->nothingnew || u->ignoredelete)
+					continue;
+				if (upgradelist_woulddelete(u->upgradelist)) {
+					todo = true;
+					break;
+				}
+			}
+		}
+	}
 
 	if (RET_WAS_ERROR(result) || !todo) {
 		for (d=distributions ; d != NULL ; d=d->next) {
