@@ -31,10 +31,10 @@ void updates_freeupdatedistributions(/*@only@*/struct update_distribution *d);
 
 retvalue updates_calcindices(struct update_pattern *, struct distribution *, /*@out@*/struct update_distribution **);
 
-retvalue updates_update(struct database *, struct update_distribution *, bool nolistsdownload, bool skipold, enum spacecheckmode mode, off_t reserveddb, off_t reservedother);
-retvalue updates_checkupdate(struct database *, struct update_distribution *, bool nolistsdownload, bool skipold);
-retvalue updates_dumpupdate(struct database *, struct update_distribution *, bool nolistsdownload, bool skipold);
-retvalue updates_predelete(struct database *, struct update_distribution *, bool nolistsdownload, bool skipold);
+retvalue updates_update(struct update_distribution *, bool /*nolistsdownload*/, bool /*skipold*/, enum spacecheckmode, off_t /*reserveddb*/, off_t /*reservedother*/);
+retvalue updates_checkupdate(struct update_distribution *, bool /*nolistsdownload*/, bool /*skipold*/);
+retvalue updates_dumpupdate(struct update_distribution *, bool /*nolistsdownload*/, bool /*skipold*/);
+retvalue updates_predelete(struct update_distribution *, bool /*nolistsdownload*/, bool /*skipold*/);
 
 retvalue updates_cleanlists(const struct distribution *, const struct update_pattern *);
 #endif
